@@ -87,25 +87,11 @@ class DockerCompose(object):
 
         print("docker compose command: %s" % (" ".join(command)))
 
-        try:
-            process = subprocess.Popen(
-                command, stdout=subprocess.PIPE, stderr=subprocess.STDOUT
-            )
+        process = subprocess.Popen(command)
+        exit_code = process.wait()
+        if exit_code != 0:
+            raise RuntimeError("Training failed. exited with code: " + str(exit_code))
 
-            exit_code = None
-            while exit_code is None:
-                stdout = process.stdout.readline()
-                if stdout is not None and isinstance(stdout, bytes):
-                    sys.stdout.write(str(stdout))
-                elif stdout is not None and isinstance(stdout, str):
-                    sys.stdout.write(stdout)
-
-                exit_code = process.poll()
-
-            if exit_code != 0:
-                raise RuntimeError("Training failed. exited with code: " + str(exit_code))
-        except RuntimeError as e:
-            raise RuntimeError("Training failed. run: " + str(e))
 
     def _generate_host_config(self, host, volumes, envs, command):
         host_volumes = []
